error_detail={
0x1001: 'Internal error. The consistency of the data was lost.',

0x1002: 'Internal error. The consistency of the data was lost.',
0x1003: 'Internal error. The consistency of the data was lost.',
0x1004: 'The length of the data exceeds HPDF_LIMIT_MAX_STRING_LEN.',

0x1005: 'Cannot get a pallet data from PNG image.',

0x1007: 'The count of elements of a dictionary exceeds HPDF_LIMIT_MAX_DICT_ELEMENT',

0x1008: 'Internal error. The consistency of the data was lost.',
0x1009: 'Internal error. The consistency of the data was lost.',
0x100A: 'Internal error. The consistency of the data was lost.',
0x100B: 'HPDF_SetPermission() OR HPDF_SetEncryptMode() was called before a password is set.',

0x100C: 'Internal error. The consistency of the data was lost.',

0x100E: 'Tried to register a font that has been registered.',

0x100F: 'Cannot register a character to the japanese word wrap characters list.',


0x1011: 'Tried to set the owner password to NULL.\nThe owner password and user password is the same.',
0x1013: 'Internal error. The consistency of the data was lost.',
0x1014: 'The depth of the stack exceeded HPDF_LIMIT_MAX_GSTATE.',

0x1015: 'Memory allocation failed.',

0x1016: 'File processing failed. (A detailed code is set.)',

0x1017: 'Cannot open a file. (A detailed code is set.)',


0x1019: 'Tried to load a font that has been registered.',
0x101A: 'The format of a font-file is invalid .\nInternal error. The consistency of the data was lost.',
0x101B: 'Cannot recognize a header of an afm file.',

0x101C: 'The specified annotation handle is invalid.',


0x101E: 'Bit-per-component of a image which was set as mask-image is invalid.',

0x101F: 'Cannot recognize char-matrics-data of an afm file.',
0x1020: '1. The color_space parameter of HPDF_LoadRawImage is invalid.\n2. Color-space of a image which was set as mask-image is invalid.\n3. The function which is invalid in the present color-space was invoked.',

0x1021: 'Invalid value was set when invoking HPDF_SetCommpressionMode().',

0x1022: 'An invalid date-time value was set.',

0x1023: 'An invalid destination handle was set.',


0x1025: 'An invalid document handle is set.',
0x1026: 'The function which is invalid in the present state was invoked.',
0x1027: 'An invalid encoder handle is set.',
0x1028: 'A combination between font and encoder is wrong.',


0x102B: 'An Invalid encoding name is specified.',

0x102C: 'The length of the key of encryption is invalid.',

0x102D: '1. An invalid font handle was set.\n2. Unsupported font format.',

0x102E: 'Internal error. The consistency of the data was lost.',
0x102F: 'A font which has the specified name is not found.',

0x1030: 'Unsupported image format.',

0x1031: 'Unsupported image format.',
0x1032: 'Cannot read a postscript-name from an afm file.',
0x1033: '1. An invalid object is set.\n2. Internal error. The consistency of the data was lost.',
0x1034: 'Internal error. The consistency of the data was lost.',
0x1035: '1. Invoked HPDF_Image_SetColorMask() against the image-object which was set a mask-image.',

0x1036: 'An invalid outline-handle was specified.',

0x1037: 'An invalid page-handle was specified.',

0x1038: 'An invalid pages-handle was specified. (internal error)',

0x1039: 'An invalid value is set.',


0x103B: 'Invalid PNG image format.',
0x103C: 'Internal error. The consistency of the data was lost.',
0x103D: 'Internal error. The "_FILE_NAME" entry for delayed loading is missing.',

0x103F: 'Invalid .TTC file format.',

0x1040: 'The index parameter was exceed the number of included fonts',

0x1041: 'Cannot read a width-data from an afm file.',
0x1042: 'Internal error. The consistency of the data was lost.',
0x1043: 'An error has returned from PNGLIB while loading an image.',

0x1044: 'Internal error. The consistency of the data was lost.',
0x1045: 'Internal error. The consistency of the data was lost.',

0x1049: 'Internal error. The consistency of the data was lost.',
0x104A: 'Internal error. The consistency of the data was lost.',
0x104B: 'Internal error. The consistency of the data was lost.',
0x104C: 'There are no graphics-states to be restored.',

0x104D: 'Internal error. The consistency of the data was lost.',
0x104E: 'The current font is not set.',

0x104F: 'An invalid font-handle was specified.',

0x1050: 'An invalid font-size was set.',

0x1051: 'See Graphics mode.',

0x1052: 'Internal error. The consistency of the data was lost.',
0x1053: 'The specified value is not a multiple of 90.',

0x1054: 'An invalid page-size was set.',
0x1055: 'An invalid image-handle was set.',

0x1056: 'The specified value is out of range.',

0x1057: 'The specified value is out of range.',
0x1058: 'Unexpected EOF marker was detected.',

0x1059: 'Internal error. The consistency of the data was lost.',

0x105B: 'The length of the specified text is too long.',

0x105C: 'The execution of a function was skipped because of other errors.',

0x105D: 'This font cannot be embedded. (restricted by license)',

0x105E: 'Unsupported ttf format. (cannot find unicode cmap.)',

0x105F: 'Unsupported ttf format.',
0x1060: 'Unsupported ttf format. (cannot find a necessary table) ',
0x1061: 'Internal error. The consistency of the data was lost.',
0x1062: '1. The library is not configured to use PNGLIB.\n2. Internal error. The consistency of the data was lost.',
0x1063: 'Unsupported Jpeg format.',
0x1064: 'Failed to parse .PFB file.',

0x1065: 'Internal error. The consistency of the data was lost.',
0x1066: 'An error has occurred while executing a function of Zlib.',

0x1067: 'An error returned from Zlib.',

0x1068: 'An invalid URI was set.',

0x1069: 'An invalid page-layout was set.',

0x1070: 'An invalid page-mode was set.',

0x1071: 'An invalid page-num-style was set.',

0x1072: 'An invalid icon was set.',

0x1073: 'An invalid border-style was set.',

0x1074: 'An invalid page-direction was set.',

0x1075: 'An invalid font-handle was specified.',

}